# Hacenada

Write do-nothing scripts in a declarative (ini) syntax



## Change Log

### [0.1.2] - 2021.01.14
  - First numbered release.
  - Current features:
    - Parse a toml script (only type=description and type=message for now)
    - Display questions and save answers in a tinydb
    - Recover state between runs, or start over
    - After the last step, write a log with what happened
    - Markdown, TOML and JSON print output of the script+answers
    - Python 3.7, 3.8, 3.9 support

[0.1.2]: https://github.com/corydodt/Codado/tree/v0.1.2
